
(function($) {

	"use strict"

	$.fn.extend({

		mapboxMapify: function( options ) {

			var settings = $.extend({
				height        : '300px',
				lat           : 43.6568,
				lng           : -79.4512,
				lock          : 'unlock',
				lat_input     : 'geo_lat',
				lng_input     : 'geo_lng',
				lock_input    : 'geo_map_lock_status'
			}, options );

			var that = $( this );

			/* Do this for each element */
			return this.each( function(){

				/* Prepare
				 ------------------------------------------ */

				/* Always add wrapper for consistency */
				that.wrap( '<div class="mapify"><span id="geocoder" class="geocoder"></span></div>' );

				/* Wrap El Vars */
				var mapifyEl = that.parents( '.mapify' );

				/* Add Map */
				if ( ! $( "#" + settings.id ).length ) {
					mapifyEl.append( '<div id="map-canvas" class="map-canvas" style="width:100%; height:' + settings.height + ';"></div>' );
				}

				/* Vars */
				var addressInput = that;
				var mapCanvas    = mapifyEl.find( '.map-canvas' );
				var map;
				var marker;

				/* Method Handler
				 ------------------------------------------ */
				var mapifyHandler = {

					/* Init
					 ------------------------------------------ */
					init: function(){
						mapifyHandler.loadMap();
					},

					/* Load Map
					 ------------------------------------------ */
					loadMap: function() {

						if ( typeof mapboxgl !== "object" ) {
							return;
						}

						mapboxgl.accessToken = KnowhereJobManager.MapConfig.AccessToken;

						var LngLat = new mapboxgl.LngLat(settings.lng, settings.lat);

						var map = new mapboxgl.Map({
							container: mapCanvas[0],
							style: 'mapbox://styles/mapbox/streets-v10',
							center: LngLat,
							zoom: 8,
							trackResize: true
						});

						marker = new mapboxgl.Marker()
							.setLngLat(LngLat)
							.addTo(map);

						var geocoder = new MapboxGeocoder({
							accessToken: mapboxgl.accessToken,
							mapboxgl: mapboxgl,
							marker: true,
							placeholder: settings.placeholder
						});

						document.getElementById('geocoder').appendChild(geocoder.onAdd(map));

						map.on('load', function () {
							map.resize();

							geocoder.on('result', function (ev) {
								mapifyHandler.SetCoordinate(ev.result);
							});
						});

					},

					SetCoordinate: function(result) {
						mapifyHandler.updateAddress(result);
					},

					/* Utility
					 ------------------------------------------ */

					/* Update Address by Position */
					updateAddress : function( result ) {
						addressInput.val(result.place_name);
					},

				};

				/* Load Init */
				mapifyHandler.init();

			});
		},

	});

	var map, markers, custom_html_icon, $body = $('body'), $window = $(window);

	function knowhere_empty (data) {
		if ( typeof( data ) == 'number' || typeof( data ) == 'boolean' ) { return false; }
		if ( typeof( data ) == 'undefined' || data === null ) { return true; }
		if ( typeof( data.length ) != 'undefined' ) { return data.length === 0; }
		var count = 0;
		for ( var i in data ) {
			if ( Object.prototype.hasOwnProperty.call(data, i) ) { count++; }
		}
		return count === 0;
	}

	function customizePadding (window) {

		var $content = $('.kw-page-listings:not(.kw-page-add-listing) .kw-content-area'),
			$pageContent = $('.kw-page-content.kw-right-sidebar, .kw-page-content.kw-no-sidebar'),
			$pageListings = $('.kw-page-listings'),
			$map = $pageListings.find('.kw-listings-gmap'),
			$header = $pageListings.find('.kw-header'),
			$leftPosition = $pageListings.find('.kw-left-position'),
			$headerTop = $pageListings.find('.kw-header-top'),
			flexRight = $pageListings.find('.kw-flex-right'),
			finderSearch = $('.kw-finder-filters'),
			finderListings = $('.kw-finder-listings'),
			finderExtend = $('.kw-finder-extend'),
			headerHeight = $header.outerHeight(),
			headerHeightWithAdminBar = headerHeight,
			position = headerHeight;

		if ( $pageContent.length ) {
			$content = $pageContent;
		}

		if ( !$pageListings.length ) return;


		if ( finderExtend.length && $leftPosition.hasClass('kw-left-position-extend') ) {
			position = finderExtend.position().top + 30;
		}

		if ( window.width() < 993 || $pageListings.hasClass('kw-page-add-listing') || $pageListings.hasClass('kw-has-no-listings') ) {
			$content.css( 'marginTop', '' );
			return;
		}

		if ( $('#wpadminbar').length ) {
			headerHeightWithAdminBar += $('#wpadminbar').outerHeight();
		}

		if ( $headerTop.length ) {
			$headerTop.css( { 'height': headerHeightWithAdminBar } );
		}

		if ( $header.css('position') == 'fixed' || $header.css('position') == 'absolute' ) {
			$content.css( 'marginTop', headerHeightWithAdminBar );
		}

		if ( $leftPosition.length && !$leftPosition.hasClass('kw-left-position-extend') ) {

			if ( finderSearch.length && finderListings.length && flexRight.length ) {
				finderSearch.add(finderListings).add(flexRight).css({'height': 'calc(100vh - ' + headerHeightWithAdminBar + 'px)'});
			}

		} else if ( $leftPosition.hasClass('kw-left-position-extend') && !$map.hasClass('kw-flex-full-width') ) {
			$map.css('top', position);
		} else if ( $map.hasClass('kw-flex-full-width' ) ) {

		} else {
			$map
				.css( 'top', headerHeightWithAdminBar )
				.css({'height': 'calc(100vh - ' + headerHeightWithAdminBar + 'px)'});
		}

	}

	function eventHanlers() {

		var window = $(window);

		window.on('debouncedresize', function() {
			customizePadding($(this));

			setTimeout(function() {
				window.trigger('update:map');
				window.trigger('pxg:refreshmap');
			});
		});

	}

	function addPinToMap($item, tax) {
		var categories = $item.data('categories'),
			iconClass, m, $img, ratingHTML = '';

		if ( typeof categories !== "undefined" && !categories.length ) {
			iconClass = 'kw-pin kw-pin-empty';
		} else {
			iconClass = 'kw-pin';
		}

		iconClass += ' ' + $item.data('first-term-id-class');

		if ( knowhere_empty($item.data('latitude')) || knowhere_empty($item.data('longitude')) ) {
			return false;
		}

		var iconSVG = knowhere_job_manager_localize.pin_style == 'default' ? wp.template('knowhere-pin-selected-svg') : wp.template('knowhere-pin-selected-svg2'),
			emptyiconSVG = knowhere_job_manager_localize.pin_style == 'default' ? wp.template('knowhere-empty-icon-svg') : wp.template('knowhere-empty-icon-svg2'),
			$categories = $item.find('.kw-listing-item-icon').first();

		var iconHTML = "<div class='" + iconClass + "'>" + emptyiconSVG() + "</div>";

		if ( $body.is('.single-job_listing') || $body.is('.kw-page-add-listing') ) {
			if ( $('.kw-single-map-category-icon').length ) {
				iconHTML = "<div class='" + iconClass + "'>" + iconSVG() + "<div class='kw-pin-icon'>" + $('.kw-single-map-category-icon').html() + "</div></div>";
			}
		} else if ( $categories.length ) {
			iconHTML = "<div class='" + iconClass + "'>" + iconSVG() + "<div class='kw-pin-icon'>" + $categories.html() + "</div></div>";
		}

		m = L.marker([$item.data('latitude'), $item.data('longitude')], {
			icon: new custom_html_icon({
				html: iconHTML
			})
		});

		if ( typeof tax !== "undefined" ) {

			if ( knowhere_empty($item.data('img')) ) { } else {
				$img = '<img src="'+ $item.data('img') +'" alt="" />';
			}

			$item.hover(function() {
				$(m._icon).find('.kw-pin').addClass('kw-pin-selected');
			}, function() {
				$(m._icon).find('.kw-pin').removeClass('kw-pin-selected');
			});

			var event = knowhere_job_manager_localize.pintpoint_event ? knowhere_job_manager_localize.pintpoint_event : 'click';

			$item.find('.kw-listing-item-pintpoint')[event](function(e) {
				e.preventDefault();

				map.setView([$item.data('latitude'), $item.data('longitude')], 20);
				$(window).on('update:map', function() {
					map.setView([$item.data('latitude'), $item.data('longitude')], 20);
				});
			});

			var rating = $item.find('.kw-card-rating');

			if ( rating.length ) {
				ratingHTML = rating.length ? rating.html() : "";
			}

			var phone = $item.data('phone') ? '<div class="kw-popup-phone"><a href="tel://' + $item.data('phone') + '">' + $item.data('phone') + '</a></div>' : '';

			m.bindPopup(
				"<div class='kw-popup'><a  href='" + $item.data('permalink') + "'>" + $img + "</a>" +
				"<div class='kw-popup-content'>" +
				"<a href='" + $item.data('permalink') + "'><h5 class='kw-popup-title'>" + $item.find('.kw-listing-item-title a').html() + "</h5></a>" + ratingHTML +
				"<div class='kw-popup-address'>" + $item.find('.kw-listing-item-location').html() + "</div>" + phone +
				"<div class='kw-open-hours-status "+ $item.data('open-hours-status') +"'>" + $item.data('open-hours-text') + "</div></div>" +
				"</div>").openPopup();

		}

		markers.addLayer(m);

		return true;
	}

	function updateListing($total) {

		var $listings = $('.job_listings'),
			$listing = $('.job_listing', $listings),
			listingWithLocation = 0;

		if ( !$listing.length ) {
			return;
		}

		if ( $listing.find('.kw-rating').length ) {
			$.knowhere.templateHelpers.productRating($listing.find('.kw-rating'));
		}

		if ( $listing.find('.kw-share-popup-link').length ) {
			KnowhereJobManager.popupLink($listing.find('.kw-share-popup-link'));
		}

		if ( $listing.find('.kw-property-slideshow.owl-carousel').length ) {
			$.knowhere.templateHelpers.propertySlideshow($listing.find('.kw-property-slideshow.owl-carousel'));
		}

		if ( typeof $total !== 'undefined' ) {
			$('.kw-results-count').replaceWith('<div class="kw-results-count">' + $total + ' ' + knowhere_job_manager_localize.strings['results'] + '</div>');
		} else {
			$('.kw-results-count').replaceWith('<div class="kw-results-count">' + $listing.length + ' ' + knowhere_job_manager_localize.strings['results'] + '</div>');
		}

		if ( $('.kw-listings-gmap').length && typeof map !== "undefined" ) {

			map.removeLayer(markers);

			markers = new L.MarkerClusterGroup({
				showCoverageOnHover: false
			});

			$listing.each(function(i, obj) {

				var cardHasLocation = addPinToMap($(obj), true);

				if ( cardHasLocation ) {
					listingWithLocation += 1;
				}
			});

			if ( listingWithLocation != 0 ) {
				map.fitBounds(markers.getBounds(), {
					padding: [50, 50]
				});
				map.addLayer(markers);

				var mapZoom = map.getZoom();
				var bounds = markers.getBounds();
				var lat = (bounds._northEast.lat + bounds._southWest.lat) / 2;
				var lng = (bounds._northEast.lng + bounds._southWest.lng) / 2;
				bounds = [lat, lng];

				Cookies.set('kw-bounds', JSON.stringify(bounds));
				Cookies.set('kw-mapZoom', mapZoom);

			}
		}

	}

	KnowhereJobManager.Maps = {
		options: {
			scrollWheelZoom: false,
			zoomControl: true,
			maxZoom: 19,
			fullscreenControl: true,
			skin: "skin1"
		},
		skins: [],
		init: function () { },
	}, KnowhereJobManager.Maps.Geocoder = function(e) {

		if ( $.fn.mapboxMapify ) {
			$(e).mapboxMapify(knowhere_job_manager_localize);
		}

	}, KnowhereJobManager.Maps.Map = function (e) {
		this.$el = $(e);

		if ( this.$el.hasClass('kw-listings-gmap') ) {
			this.init(e);
		} else if ( this.$el.hasClass('kw-listing-widget-gmap') ) {
			this.widget_init(e);
		}

	}, KnowhereJobManager.Maps.Map.prototype.init = function (e) {

			customizePadding($window);
			eventHanlers();

			if ( !$('#kw-listings-gmap').length ) {
				$('.job_listings').on('updated_results', function(e, result) {
					updateListing(result.total_found);
				});
				return;
			}

			if ( typeof L !== "object" || !L.hasOwnProperty('map') ) {
				return;
			}

			this.options = $.extend({}, KnowhereJobManager.Maps.options, $(e).data('options'));

			map = L.map(this.$el[0], {
				scrollWheelZoom: this.options.scrollWheelZoom,
				zoomControl: this.options.zoomControl,
				maxZoom: this.options.maxZoom,
				fullscreenControl: this.options.fullscreenControl
			});

			L.mapboxGL({
				accessToken: KnowhereJobManager.MapConfig.AccessToken,
				style: this.options.skin == 'custom' ? KnowhereJobManager.MapConfig.CustomSkin : KnowhereJobManager.Maps.skins[this.options.skin] ? KnowhereJobManager.Maps.skins[this.options.skin] : KnowhereJobManager.Maps.skins.skin1
			}).addTo(map);

			markers = new L.MarkerClusterGroup({
				spiderfyOnMaxZoom: true,
				showCoverageOnHover: true
			});

			custom_html_icon = L.HtmlIcon.extend({
				options: {
					iconSize: [50, 60],
					iconAnchor: [25, 60],
					popupAnchor: [-1, -60]
				}
			});

			map._onResize();

			$window.on('pxg:refreshmap', function () {
				map._onResize();
			});

			if ( !$('#kw-listings-gmap').is('.kw-listing-widget-gmap') ) {

				updateListing();

				$('.job_listings').on('updated_results', function(e, result) {
					updateListing(result.total_found);
				});

				$(document).on('facetwp-loaded facetwp-refresh', function(e, result) {
					if ( $('select.facetwp-dropdown').length ) {
						$('select.facetwp-dropdown').chosen();
					}
					updateListing();
				});

			}

		}, KnowhereJobManager.Maps.Map.prototype.widget_init = function (e) {

			if ( typeof L !== "object" || !L.hasOwnProperty('map') ) {
				return;
			}

			this.options = $.extend({}, KnowhereJobManager.Maps.options, $(e).data('options'));

			var map = L.map(this.$el[0], {
				scrollWheelZoom: this.options.scrollWheelZoom,
				zoomControl: this.options.zoomControl,
				maxZoom: this.options.maxZoom,
				fullscreenControl: this.options.fullscreenControl
			});

			L.mapboxGL({
				accessToken: KnowhereJobManager.MapConfig.AccessToken,
				style: this.options.skin == 'custom' ? KnowhereJobManager.MapConfig.CustomSkin : KnowhereJobManager.Maps.skins[this.options.skin] ? KnowhereJobManager.Maps.skins[this.options.skin] : KnowhereJobManager.Maps.skins.skin1
			}).addTo(map);

			markers = new L.MarkerClusterGroup({
				showCoverageOnHover: true
			});

			custom_html_icon = L.HtmlIcon.extend({
				options: {
					iconSize: [50, 60],
					iconAnchor: [25, 60],
					popupAnchor: [-1, -60]
				}
			});

			$window.on('pxg:refreshmap', function () {
				map._onResize();
			});

			var $item = $('.single_job_listing');

			if ( typeof $item.data('latitude') !== "undefined" && typeof $item.data('longitude') !== "undefined" ) {

				addPinToMap($item);
				map.addLayer(markers);
				map.setView([$item.data('latitude'), $item.data('longitude')], 13);
				$(window).on('update:map', function () {
					map.setView([$item.data('latitude'), $item.data('longitude')], 13);
				});

			} else {
				$(el).hide();
			}

	}, KnowhereJobManager.Maps.skins = {
		skin1: "mapbox://styles/mapbox/streets-v10",
		skin2: "mapbox://styles/mapbox/outdoors-v10",
		skin3: "mapbox://styles/mapbox/light-v9",
		skin4: "mapbox://styles/mapbox/dark-v9",
		skin5: "mapbox://styles/mapbox/satellite-streets-v10",
		skin6: "mapbox://styles/mapbox/navigation-preview-day-v4",
		skin7: "mapbox://styles/mapbox/navigation-preview-night-v4",
		skin8: "mapbox://styles/mapbox/navigation-guidance-day-v4",
		skin9: "mapbox://styles/mapbox/navigation-guidance-night-v4"
	}, KnowhereJobManager.Maps.init = function () {

		var $maps = $('.kw-listings-gmap, .kw-listing-widget-gmap');

		if ( $maps.length ) {
			$window.on('load', function () {
				$maps.each(function (i, el) {
					new KnowhereJobManager.Maps.Map(el);
				})
			});
		}

		var $locations = $('#job_location, #candidate_location');

		if ( $locations.length ) {

			$window.on('load', function () {
				$locations.each(function (i, el) {
					new KnowhereJobManager.Maps.Geocoder(el);
				})
			});
		}

	}, KnowhereJobManager.Maps.init();

})(jQuery);