<?php

namespace KnowherePro\Ext\Maps\Platforms\Mapbox;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Mapbox {

	use \KnowherePro\Src\Traits\Instantiatable;

	public
		$api_key,
		$custom_skin;

	public function __construct() {

		global $knowhere_settings;

		$this->skins = [];
		$this->custom_skin = '';

		$this->api_key = $knowhere_settings['mapbox-token'];
		$this->custom_skin = $knowhere_settings['map-style'];
		$this->set_skins();

		add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ], 25 );
		add_filter( 'knowhere/functions/localize-data', [ $this, 'localize_data' ], 25 );
	}

	public function enqueue_scripts() {

		wp_enqueue_script( 'mapbox', get_theme_file_uri('config-job-manager/assets/dist/maps/mapbox/mapbox.js'), [], null, true );

		wp_enqueue_script( 'mapbox-gl', 'https://api.tiles.mapbox.com/mapbox-gl-js/v0.53.1/mapbox-gl.js', array(), null, true );
		wp_enqueue_script( 'mapbox-gl-geocoder', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.0.0/mapbox-gl-geocoder.min.js', array( 'mapbox' ), null, true );

		wp_enqueue_style( 'mapbox-gl-css', 'https://api.tiles.mapbox.com/mapbox-gl-js/v0.53.1/mapbox-gl.css' );
		wp_enqueue_style( 'mapbox-gl-geocoder-css', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.0.0/mapbox-gl-geocoder.css' );

		wp_enqueue_script( 'leaflet-mapbox', get_theme_file_uri('js/libs/mapbox/leaflet-mapbox-gl.js'), ['jquery', 'mapbox-gl', 'mapbox-gl-geocoder', 'mapbox'], null, true );

	}

	public function set_skins() {

		if ( !empty($this->custom_skin) ) {
			$this->custom_skin = $this->custom_skin;
		}

		$this->skins['skin1'] = esc_html__('Vanilla', 'knowherepro');
		$this->skins['skin2'] = esc_html__('Midnight', 'knowherepro');
		$this->skins['skin3'] = esc_html__('Grayscale', 'knowherepro');
		$this->skins['skin4'] = esc_html__('Blue Water', 'knowherepro');
		$this->skins['skin5'] = esc_html__('Nature', 'knowherepro');
		$this->skins['skin6'] = esc_html__('Light', 'knowherepro');
		$this->skins['skin7'] = esc_html__('Teal', 'knowherepro');
		$this->skins['skin8'] = esc_html__('Vanilla', 'knowherepro');
		$this->skins['skin9'] = esc_html__('Violet', 'knowherepro');
	}

	public function localize_data( $data ) {
		$data['MapConfig']['AccessToken'] = $this->api_key;
		$data['MapConfig']['CustomSkin'] = $this->custom_skin;
		return $data;
	}

}