<?php
/**
 * Plugin integrations.
 */

abstract class Knowhere_Integration {

	public $includes = array();
	public $directory;

	/**
	 * Add customizer support.
	 *
	 * @since 3.5.0
	 * @access public
	 * @var $has_customizer
	 */
	public function __construct( $directory ) {

		$this->directory = $directory;
		$this->includes();
		$this->init();
		$this->setup_actions();
		$this->internal_actions();

	}

	private function includes() {
		if ( empty( $this->includes ) ) {
			return;
		}

		foreach ( $this->includes as $file ) {
			require_once( trailingslashit( $this->directory ) . $file );
		}
	}

	public function init() {}

	public function setup_actions() {}

	private function internal_actions() {
		add_filter( 'body_class', array( $this, 'body_class' ) );
	}

	public function body_class( $classes ) {
		return $classes;
	}

	public function customizer_output_styles() {
		$files = glob( $this->get_dir() . 'customizer/definitions/output-styles/*.php' );

		if ( empty( $files ) ) {
			return;
		}

		foreach ( $files as $file ) {
			include_once( $file );
		}
	}

}
