<?php
/**
 * Shortcodes
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit ; // Exit if accessed directly.
}
if ( ! class_exists( 'SUMOMembership_Shortcodes' ) ) {

    /**
     * Class.
     */
    class SUMOMembership_Shortcodes {

        /**
         * Class Initialization.
         */
        public static function init() {

            $shortcodes = array(
                /* My Account Shortcodes */
                'sumo_member_details' ,
                'sumo_members' ,
                'sumo_members_based_on_plans' ,
                /* Membership Restriction Shortcodes */
                'membership_product(s)' ,
                'default_membership_plan(s)' ,
                'login_link' ,
                'membership'
                    ) ;

            foreach ( $shortcodes as $shortcode_name ) {

                add_shortcode( $shortcode_name , array( __CLASS__ , 'process_shortcode' ) ) ;
            }
        }

        /**
         * Process Shortcode
         */
        public static function process_shortcode( $atts , $content , $tag ) {

            $shortcodename = str_replace( array( '(' , ')' ) , array( '' , '' ) , $tag ) ;
            $function      = 'shortcode_' . $shortcodename ;

            switch ( $shortcodename ) {

                case 'sumo_member_details':
                case 'sumo_members':
                case 'sumo_members_based_on_plans':
                case 'membership_products':
                case 'default_membership_plans':
                case 'login_link':
                case 'membership' ;

                    ob_start() ;
                    self::$function( $atts , $content ) ; // output for shortcode
                    $content = ob_get_contents() ;
                    ob_end_clean() ;

                    break ;
            }

            return $content ;
        }

        /*
         * Display Membership Information
         */

        public static function shortcode_sumo_member_details( $atts , $content ) {

            SUMOMemberships_Account_Page::display_membership_information() ;
        }

        /*
         * Display All Members.
         */

        public static function shortcode_sumo_members( $atts , $content ) {

            $args  = array( 'post_type' => 'sumomembers' , 'numberposts' => -1 , 'fields' => 'ids' , 'post_status' => 'published' ) ;
            $posts = get_posts( $args ) ;
            ?>
            <table>
                <tbody>
                    <tr>

                        <th><?php _e( 'S.no' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Name' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Avatar' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Plans' , 'sumomemberships' ) ?></th>
                    </tr>

                    <?php
                    $sno   = 1 ;
                    if ( ! empty( $posts ) ) {

                        foreach ( $posts as $member_id ) {

                            $user_id = get_post_meta( $member_id , 'sumomemberships_userid' , true ) ;
                            if ( $user_id != '' ) {

                                $getdatatodisplay = get_post_meta( $member_id , 'sumomemberships_saved_plans' , true ) ;
                                if ( is_array( $getdatatodisplay ) && ! empty( $getdatatodisplay ) ) {

                                    $saved_plans = array() ;
                                    foreach ( $getdatatodisplay as $key => $value ) {

                                        if ( isset( $value[ 'choose_plan' ] ) && $value[ 'choose_plan' ] != '' && $value[ 'choose_status' ] == 'active' ) {

                                            $saved_plans[] = get_the_title( $value[ 'choose_plan' ] ) ;
                                        }
                                    }
                                    if ( ! empty( $saved_plans ) ) {
                                        ?><tr><td><?php echo $sno ; ?></td><?php
                                            $user_info = get_userdata( $user_id ) ;
                                            $username  = $user_info->user_login ;
                                            $useremail = $user_info->user_email ;
                                            ?><td><?php echo $username ; ?></td><?php
                                            ?><td><?php echo get_avatar( $user_id , 50 , '' , $username , '' ) ; ?></td><?php
                                            ?><td><?php echo implode( ', ' , $saved_plans ) ; ?></td></tr><?php
                                        $sno ++ ;
                                    }
                                }
                            }
                        }
                    }
                    ?>
                </tbody>
            </table>

            <?php
        }

        /*
         * Display Members Based On Plans.
         */

        public static function shortcode_sumo_members_based_on_plans( $atts , $content ) {

            extract( shortcode_atts( array(
                'plan_ids' => '' ,
                            ) , $atts ) ) ;
            $display_plans = explode( ',' , $plan_ids ) ;
            $args          = array( 'post_type' => 'sumomembers' , 'numberposts' => -1 , 'fields' => 'ids' , 'post_status' => 'published' ) ;
            $posts         = get_posts( $args ) ;
            ?>
            <table>
                <tbody>
                    <tr>

                        <th><?php _e( 'S.no' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Name' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Avatar' , 'sumomemberships' ) ?></th>
                        <th><?php _e( 'Plans' , 'sumomemberships' ) ?></th>
                    </tr>

                    <?php
                    $sno           = 1 ;
                    if ( ! empty( $posts ) ) {

                        foreach ( $posts as $member_id ) {

                            $user_id = get_post_meta( $member_id , 'sumomemberships_userid' , true ) ;
                            if ( $user_id != '' ) {

                                $getdatatodisplay = get_post_meta( $member_id , 'sumomemberships_saved_plans' , true ) ;
                                if ( is_array( $getdatatodisplay ) && ! empty( $getdatatodisplay ) ) {

                                    $saved_plans = array() ;
                                    foreach ( $getdatatodisplay as $key => $value ) {

                                        if ( isset( $value[ 'choose_plan' ] ) && $value[ 'choose_plan' ] != '' && $value[ 'choose_status' ] == 'active' && in_array( $value[ 'choose_plan' ] , $display_plans ) ) {

                                            $saved_plans[] = get_the_title( $value[ 'choose_plan' ] ) ;
                                        }
                                    }

                                    if ( ! empty( $saved_plans ) ) {
                                        ?><tr><td><?php echo $sno ; ?></td><?php
                                            $user_info = get_userdata( $user_id ) ;
                                            $username  = $user_info->user_login ;
                                            $useremail = $user_info->user_email ;
                                            ?><td><?php echo $username ; ?></td><?php
                                            ?><td><?php echo get_avatar( $user_id , 50 , '' , $username , '' ) ; ?></td><?php
                                            ?><td><?php echo implode( ', ' , $saved_plans ) ; ?></td></tr><?php
                                        $sno ++ ;
                                    }
                                }
                            }
                        }
                    }
                    ?>
                </tbody>
            </table>
            <?php
        }

        /*
         * Add to Cart Membership Product - Displaying for Restriction Messages.
         */

        public static function shortcode_membership_products( $atts , $content ) {

            global $post ;

            $plan_add_to_cart_url = array() ;

            $this_id = isset( $post->ID ) ? $post->ID : 0 ;

            $membership_products = self::get_membership_products_to_disable_restriction( $this_id ) ;

            foreach ( $membership_products as $membership_product_id ) {

                $product = sumo_get_product( $membership_product_id ) ;

                if ( is_object( $product ) ) {

                    $plan_add_to_cart_url[] = '<a class="membership_add_to_cart" style="color:blue;" href="' . $product->add_to_cart_url() . '">' . $product->get_title() . '</a>' ;
                }
            }

            echo is_array( $plan_add_to_cart_url ) ? implode( " / " , array_unique( $plan_add_to_cart_url ) ) : "" ;
        }

        /*
         * Get Membership Products to Disable Restriction.
         */

        public static function get_membership_products_to_disable_restriction( $this_id ) {

            $membership_products = array() ;
            $content_access_type = get_post_meta( $this_id , 'sumomemberships_products_posts_pages_settings' , true ) ;

            if ( $content_access_type == 'with_particular_plans' ) {

                $plan_rules = sumo_get_plan_rules_added( $this_id , 'members_with_plan' ) ;

                $plan_ids = self::extract_plan_ids_from_plan_rules( $plan_rules ) ;

                foreach ( $plan_ids as $plan_id ) {

                    if ( get_post_meta( $plan_id , 'sumomemberships_plan_associated_product' , true ) != "" ) {

                        $membership_products[] = get_post_meta( $plan_id , 'sumomemberships_plan_associated_product' , true ) ;
                    }
                }
            }

            return $membership_products ;
        }

        /*
         * Get Plan Ids.
         */

        public static function extract_plan_ids_from_plan_rules( $plan_rules ) {

            $plan_ids = array() ;

            if ( is_array( $plan_rules ) ) {
                foreach ( $plan_rules as $each_rules ) {

                    $plan_ids[] = $each_rules[ 'plan_id' ] ;
                }
            }

            return $plan_ids ;
        }

        /*
         * Display Default Plans.
         */

        public static function shortcode_default_membership_plans( $atts , $content ) {

            $plan_name           = array() ;
            $default_valid_plans = get_option( 'sumomemberships_valid_default_plans' ) ;

            if ( is_array( $default_valid_plans ) && ! empty( $default_valid_plans ) ) {

                foreach ( $default_valid_plans as $plan_id ) {

                    $membership_product_id = get_post_meta( $plan_id , 'sumomemberships_plan_associated_product' , true ) ;

                    $product = sumo_get_product( $membership_product_id ) ;

                    if ( is_object( $product ) ) {

                        $plan_name[] = "<span class=sumo_default_plans style=color:green;>" . get_post_meta( $plan_id , 'sumomemberships_plan_name' , true ) . "</span>" ;
                    }
                }
            }

            echo implode( ", " , $plan_name ) ;
        }

        /*
         * Display Site Members Login Link For Guests.
         */

        public static function shortcode_login_link( $atts , $content ) {

            if ( is_user_logged_in() )
                return ;

            $login_link = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ;

            echo '<a href="' . $login_link . '" style = "color: blue; font-size: 18px;">' . $login_link . '</a>' ;
        }

        /*
         * Shortcode to Restrict the Content block on Posts or Pages based upon the Plan Slug.
         */

        public static function shortcode_membership( $atts , $content ) {

            $this_member_id = get_current_user_id() ;

            $member_post_id         = sumo_get_member_post_id( $this_member_id ) ;
            $linked_plans           = sumo_get_available_linked_plans( $member_post_id , 'active' ) ;
            $check_for_linked_users = sumo_check_linked_users_had_privilege( $this_member_id ) ;
            $bool                   = false ;
            $plan                   = "" ;
            $admin_access           = self::get_user_role_for_admin_access() ;

            /* Extract Plan Slug from the array index "plan" */
            extract( shortcode_atts( array( 'plan' => '' ) , $atts ) ) ;

            $plan_slugs = explode( "," , $plan ) ;
            foreach ( $plan_slugs as $each_slug ) {

                $plan_id = sumo_get_plan_id_from_slug( $each_slug ) ;

                /* Check if the Member not purchased this Plan Slug associated Plan then Restrict the corresponding Content. */
                if ( (sumo_is_member_purchased_any_plan( $member_post_id ) && sumo_is_plan_active( $plan_id , $member_post_id ) ) || in_array( $plan_id , $linked_plans ) || in_array( $plan_id , $check_for_linked_users ) ) {
                    $bool = true ;
                }
            }
            if ( in_array( 'allmembers' , $plan_slugs ) ) {

                if ( $member_post_id ) {

                    $member_purchased_active_plans = sumo_get_member_purchased_plans_list( $member_post_id ) ;
                    if ( ! empty( $member_purchased_active_plans ) || ! empty( $linked_plans ) || ! empty( $check_for_linked_users ) ) {
                        $bool = true ;
                    }
                } else {

                    if ( ! empty( $check_for_linked_users ) ) {
                        $bool = true ;
                    }
                }
            }
            if ( in_array( 'nonmembers' , $plan_slugs ) ) {

                if ( $member_post_id ) {

                    $member_purchased_active_plans = sumo_get_member_purchased_plans_list( $member_post_id ) ;
                    if ( empty( $member_purchased_active_plans ) && empty( $linked_plans ) && empty( $check_for_linked_users ) ) {

                        $bool = true ;
                    }
                } else {

                    if ( empty( $check_for_linked_users ) ) {

                        $bool = true ;
                    }
                }
            }

            if ( $admin_access ) {

                $bool = true ;
            }

            echo $bool ? $content : "" ;
        }

        /*
         * Display Content Restriction to Administrator With admin_access function.
         */

        public static function get_user_role_for_admin_access() {

            $this_member_id = get_current_user_id() ;
            $user_meta      = get_userdata( $this_member_id ) ;
            $user_roles     = is_object( $user_meta ) ? $user_meta->roles : '' ;
            $bool           = false ;
            if ( is_array( $user_roles ) && ! empty( $user_roles ) ) {

                foreach ( $user_roles as $role ) {

                    /*  $array refers to key and $role refers to value. eg: 0 => administrator  */
                    if ( $role === "administrator" ) {

                        $bool = true ;
                    }

                    return $bool ;
                }
            }
        }

    }

    SUMOMembership_Shortcodes::init() ;
}
